P= # Package name (should usually match the port subdir name)
V= # Upstream version identifier (can't contain -)
MAJOR=0 # Bump for backward-incompatible changes
MINOR=0 # Bump for each package release (reset when bumping MAJOR)

# Declare all sources, one per line (can't be named "build.sh"). If a file exists in the port subdir it is considered in-tree, otherwise out-of-tree. Upstream URLs should be provided for out-of-tree sources when possible.
S="
$P-$V.tar.gz http://example.com/$P-$V.tar.gz
local-fixes.patch
"

SHA512="
sha512sums for out-of-tree sources (hex and filename, separated by two spaces)
Extra lines (e.g. older versions) are OK
"

# Functions are run from the temporary build directory, which is populated with the sources and build.sh. These sources might be symlinks, so don't modify them in-place. The executing shell is run "set -e" (thus, for instance, you can use "false" to abort the build for inspection at a specific point).
build () {
	root=$PWD/root
	tar xzf $P-$V.tar.gz
	cd $P-$V
	patch -p1 <../local-fixes.patch
	# Ideally, regenerate any non-source files here (autoconf, yacc, ...)
	# $Q is the qualified package name ($P-$MAJOR.$MINOR-$V)
	./configure --prefix=/gales/pkg/$Q
	make -j$JOBS
	make install DESTDIR=$root
}

check () {
	cd $P-$V
	make check
}

# This function is run using ar.sh with standard output directed into the package script. Use the provided commands rather than emitting code directly (see gales-util/ar.sh for details).
package () {
	cd $P-$V
	f gales/pkg/$Q/doc/README
	cd ../root/gales/pkg
	a gales/pkg/$Q
	l gales/pkg/$P $Q
	l gales/command/some-cmd ../pkg/$P/bin/some-cmd
	l gales/doc/$P ../pkg/$P/doc
	l gales/man/$P ../pkg/$P/man
}
